==> dingtalk-cli-pro-0.0.53.tgz: package/README.md <==
# dingtalk-cli-pro
🌋 可插拔的企业级工具开发框架，同时支持 Window 和 Mac 平台

## 简介
🏄‍♂  dingtalk-cli-pro 支持自定义命令行插件开发，对插件从 `生成 -> 开发 -> 调试 -> 发布 -> 安装` 进行生命周期管理， 让开发者 `1s` 钟开发出自己的插件，提高生产效率，成为闪电侠⚡️

## 特性

- 📦 **开箱即用**，内置 `dev`, `build`, `generator` 和 `publish`等系统命令行
- 🎉 **插件体系**，支持自定义命令行插件开发, 覆盖从 生成 -> 开发 -> 调试 -> 发布 -> 安装 的插件开发生命周期
- ⛄️ **内置脚手架工具**，工具内置 `plugin` 和 `scaffold` 模板，让开发者轻松开发 `自定义插件` 以及 `项目开发脚手架`

## 系统命令

```
Usage: dpro [options] [command]

Options:
  -h, --help                    output usage information

Commands:
  dev|d                ️️️️Start Local Development
  build|b [options]    Build App On Local
  generator|g          Create Your Plugin OR Generator
  publish|p [options]  Publish Your App To Daily OR Online
```

## 快速上手
`dpro` 命令为 `dingtalk-cli-pro` 命令的简写，开发者可以直接使用简化命令行 `dpro` 运行命令行工具

### 安装工具
Window PC 推荐使用 `yarn` 安装

```
$ yarn global add dingtalk-cli-pro # 或者 npm install -g dingtalk-cli-pro
```

```
# 查看工具
$ dpro --help

# 项目开发
$ dpro dev

# 项目本地打包
$ dpro build 

# 项目云端构建
$ dpro p -d  # 预发环境
$ dpro p -o  # 线上环境
```

### 使用插件

```
# 安装插件
$ yarn global add dingtalk-plugin-helloworld # 或者 npm install -g dingtalk-plugin-helloworld

# 运行插件
$ dpro hellworld 

```

> 
[dingtalk-plugin-helloworld 插件源码](https://www.npmjs.com/package/dingtalk-plugin-helloworld)

### 开发插件

```
# 安装工具
$ yarn global add dingtalk-cli-pro # 或者 npm install -g dingtalk-cli-pro

# 安装插件
$ dpro g  ## 可交互命令行，按步骤操作

# 开发插件
$ vi index.js

```

## 使用案例

![](https://img.alicdn.com/tfs/TB1AxyXeUKF3KVjSZFEXXXExFXa-654-442.gif)


## 代码案例
```js

module.exports = function(dingtalk) {
  /**
  * 命令行工具
  * @see https://www.npmjs.com/package/commander
  */
 // 可以使用 dingtalk or this 作用域
 dingtalk
  // 注册插件命令 $ dpro helloworld
  .registryCommand('helloworld') 
  // 插件命令描述
  .description('welcome to dpro')
  // 运行命令回调
  .action(() => {
    this.log.warn(`Hi ${this.getGitUserInfo().username}, Welcome to dpro`);
  });
}

```

## API 接口

### 文件模块 
`dintalk.fs|this.fs`上下文对象, [Mem-fs-editor API参考文档](https://www.npmjs.com/package/mem-fs-editor)

### 命令行模块 
`dingtalk.registryCommand|this.registryCommand`上下文对象, [Commander API 参考文档](https://www.npmjs.com/package/commander)

### 可交互模块
`dingtalk.prompt|this.prompt`上下文对象, [Inquirer API 参考文档](https://www.npmjs.com/package/inquirer)

### 日志模块
`dingtalk.log|this.log`上下文对象， [Log API 参考文档](lib/log.js)


## License

[MIT](https://github.com/umijs/umi/blob/master/LICENSE)

==> dingtalk-cli-pro-0.0.60.tgz: package/README.md <==
# dingtalk-cli-pro
🌋 可插拔的企业级工具开发框架，同时支持 Window 和 Mac 平台

## 简介
🏄‍♂  dingtalk-cli-pro 支持自定义命令行插件开发，对插件从 `生成 -> 开发 -> 调试 -> 发布 -> 安装` 进行生命周期管理， 让开发者 `1s` 钟开发出自己的插件，提高生产效率，成为闪电侠⚡️

## 特性

- 📦 **开箱即用**，内置 `generator` 命令
- 🎉 **插件体系**，支持自定义命令行插件开发, 覆盖从 生成 -> 开发 -> 调试 -> 发布 -> 安装 的插件开发生命周期
- ⛄️ **内置脚手架工具**，工具内置 `plugin` 和 `scaffold` 模板，让开发者轻松开发 `自定义插件` 以及 `项目开发脚手架`

## 系统命令

```
Usage: dpro [options] [command]

Options:
  -h, --help                    output usage information

Commands:
  generator|g          Create Your Plugin OR Generator
```

## 快速上手
`dpro` 命令为 `dingtalk-cli-pro` 命令的简写，开发者可以直接使用简化命令行 `dpro` 运行命令行工具

### 安装工具
Window PC 推荐使用 `yarn` 安装

```
$ yarn global add dingtalk-cli-pro # 或者 npm install -g dingtalk-cli-pro
```

```
# 查看工具
$ dpro --help

# 项目开发
$ dpro dev

# 项目本地打包
$ dpro build 

# 项目云端构建
$ dpro p -d  # 预发环境
$ dpro p -o  # 线上环境
```

### 使用插件

```
# 安装插件
$ yarn global add dingtalk-plugin-helloworld # 或者 npm install -g dingtalk-plugin-helloworld

# 运行插件
$ dpro hellworld 

```

> 
[dingtalk-plugin-helloworld 插件源码](https://www.npmjs.com/package/dingtalk-plugin-helloworld)

### 开发插件

```
# 安装工具
$ yarn global add dingtalk-cli-pro # 或者 npm install -g dingtalk-cli-pro

# 安装插件
$ dpro g  ## 可交互命令行，按步骤操作

# 开发插件
$ vi index.js

```

## 调试插件
通过 `dingtalkrc.js` 文件配置当前插件入口文件，数组形式可以加载多个插件，配置如下
```javascript
module.exports = {
  "plugins": [
    [
      "./index.js"
    ]
  ]
}
```

### 运行命令调试
```dart
$ dpro command # 命令
```

### vscode调试
插件的开发调试支持VSCode调试， `dpro g ` 命令生成脚手架的时候预制了 `Plugin Param Test` 和 `Plugin Jest Test` 两种命令，可以运行 Vscode 的 debug 模式查看运行。

- Plugin Param Test： 可以在Vscode 的 Debug 模式下设置断点
- Plugin Jest Test： 可以跑 Jest 的测试用例 

## 使用案例

![](https://img.alicdn.com/tfs/TB1AxyXeUKF3KVjSZFEXXXExFXa-654-442.gif)


## 代码案例
```js

module.exports = function(dingtalk) {
  /**
  * 命令行工具
  * @see https://www.npmjs.com/package/commander
  */
 // 可以使用 dingtalk or this 作用域
 dingtalk
  // 注册插件命令 $ dpro helloworld
  .registryCommand('helloworld') 
  // 插件命令描述
  .description('welcome to dpro')
  // 运行命令回调
  .action(() => {
    this.log.warn(`Hi ${this.getGitUserInfo().username}, Welcome to dpro`);
  });
}
```
## 系统工具命令
```json
{
  "dingtalk-plugin-react": "*",
  "dingtalk-plugin-rollup-ts": "*",
  "dingtalk-plugin-typescript": "*",
  "dingtalk-plugin-webpack-react": "*",
  "dingtalk-plugin-eapp-tstojs": "*",
  "dingtalk-plugin-eapp-ts": "*"
}
```

## API 接口

### 文件模块 
`dintalk.fs|this.fs`上下文对象, [Mem-fs-editor API参考文档](https://www.npmjs.com/package/mem-fs-editor)

### 命令行模块 
`dingtalk.registryCommand|this.registryCommand`上下文对象, [Commander API 参考文档](https://www.npmjs.com/package/commander)

### 可交互模块
`dingtalk.prompt|this.prompt`上下文对象, [Inquirer API 参考文档](https://www.npmjs.com/package/inquirer)

### 日志模块
`dingtalk.log|this.log`上下文对象， [Log API 参考文档](lib/log.js)


## License

[MIT](https://github.com/umijs/umi/blob/master/LICENSE)
